module.exports = defineTest({
	description: 'detects side-effects in chained string method arguments'
});
